# wire4_client

Wire4Client - the Ruby gem for the Wire4RestAPI

Referencia de la API de Wire4

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.11
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build wire4_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./wire4_client-1.0.11.gem
```
(for development, run `gem install --dev ./wire4_client-1.0.11.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'wire4_client', '~> 1.0.11'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'wire4_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'wire4_client'

api_instance = Wire4Client::AutorizacinDeDepsitosApi.new

authorization = 'authorization_example' # String | Header para token

subscription = 'subscription_example' # String | Es el identificador de la suscripción a esta API.


begin
  #Consulta autorización de depósitos
  result = api_instance.get_deposit_auth_configurations(authorization, subscription)
  p result
rescue Wire4Client::ApiError => e
  puts "Exception when calling AutorizacinDeDepsitosApi->get_deposit_auth_configurations: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://sandbox-api.wire4.mx/wire4/1.0.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Wire4Client::AutorizacinDeDepsitosApi* | [**get_deposit_auth_configurations**](docs/AutorizacinDeDepsitosApi.md#get_deposit_auth_configurations) | **GET** /subscriptions/{subscription}/configurations/deposit-authorization | Consulta autorización de depósitos
*Wire4Client::AutorizacinDeDepsitosApi* | [**put_deposit_auth_configurations**](docs/AutorizacinDeDepsitosApi.md#put_deposit_auth_configurations) | **PUT** /subscriptions/{subscription}/configurations/deposit-authorization | Habilita / Deshabilita la autorización de depósitos
*Wire4Client::ComprobanteElectrnicoDePagoCEPApi* | [**obtain_transaction_cep_using_post**](docs/ComprobanteElectrnicoDePagoCEPApi.md#obtain_transaction_cep_using_post) | **POST** /ceps | Consulta de CEP
*Wire4Client::ContactoApi* | [**send_contact_using_post**](docs/ContactoApi.md#send_contact_using_post) | **POST** /contact | Solicitud de contacto
*Wire4Client::ContractsDetailsApi* | [**create_authorization**](docs/ContractsDetailsApi.md#create_authorization) | **POST** /onboarding/accounts/authorize | Devuelve la URL para autorización del usuario Monex
*Wire4Client::ContractsDetailsApi* | [**obtain_authorized_users**](docs/ContractsDetailsApi.md#obtain_authorized_users) | **GET** /onboarding/accounts/{requestId}/authorized-users | Obtiene los usuarios autorizados
*Wire4Client::ContractsDetailsApi* | [**obtain_authorized_users_by_contract**](docs/ContractsDetailsApi.md#obtain_authorized_users_by_contract) | **GET** /onboarding/accounts/authorized-users | Obtiene los usuarios autorizados por contrato
*Wire4Client::ContractsDetailsApi* | [**obtain_contract_details**](docs/ContractsDetailsApi.md#obtain_contract_details) | **POST** /onboarding/accounts/details | Obtiene los detalles de la empresa del contrato
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**authorize_accounts_pending_put**](docs/CuentasDeBeneficiariosSPEIApi.md#authorize_accounts_pending_put) | **PUT** /subscriptions/{subscription}/beneficiaries/pending | Solicitud para agrupar cuentas de beneficiarios SPEI/SPID en estado pendiente.
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**delete_account_using_delete**](docs/CuentasDeBeneficiariosSPEIApi.md#delete_account_using_delete) | **DELETE** /subscriptions/{subscription}/beneficiaries/spei/{account} | Elimina la cuenta del beneficiario
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**get_available_relationships_monex_using_get**](docs/CuentasDeBeneficiariosSPEIApi.md#get_available_relationships_monex_using_get) | **GET** /subscriptions/{subscription}/beneficiaries/relationships | Consulta de relaciones
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**get_beneficiaries_by_request_id**](docs/CuentasDeBeneficiariosSPEIApi.md#get_beneficiaries_by_request_id) | **GET** /subscriptions/{subscription}/beneficiaries/spei/{requestId} | Consulta los beneficiarios por el identificador de la petición de registro
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**get_beneficiaries_for_account_using_get**](docs/CuentasDeBeneficiariosSPEIApi.md#get_beneficiaries_for_account_using_get) | **GET** /subscriptions/{subscription}/beneficiaries/spei | Consulta los beneficiarios registrados
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**pre_register_accounts_using_post**](docs/CuentasDeBeneficiariosSPEIApi.md#pre_register_accounts_using_post) | **POST** /subscriptions/{subscription}/beneficiaries/spei | Pre-registro de cuentas de beneficiarios SPEI®.
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**remove_beneficiaries_pending_using_delete**](docs/CuentasDeBeneficiariosSPEIApi.md#remove_beneficiaries_pending_using_delete) | **DELETE** /subscriptions/{subscription}/beneficiaries/spei/request/{requestId} | Eliminación de beneficiarios SPEI® sin confirmar
*Wire4Client::CuentasDeBeneficiariosSPEIApi* | [**update_amount_limit_account_using_put**](docs/CuentasDeBeneficiariosSPEIApi.md#update_amount_limit_account_using_put) | **PUT** /subscriptions/{subscription}/beneficiaries/spei/{account} | Solicitud para actualizar el monto límite de una cuenta
*Wire4Client::CuentasDeBeneficiariosSPIDApi* | [**get_spid_beneficiaries_for_account**](docs/CuentasDeBeneficiariosSPIDApi.md#get_spid_beneficiaries_for_account) | **GET** /subscriptions/{subscription}/beneficiaries/spid | Consulta los beneficiarios SPID registrados
*Wire4Client::CuentasDeBeneficiariosSPIDApi* | [**pre_register_accounts_using_post1**](docs/CuentasDeBeneficiariosSPIDApi.md#pre_register_accounts_using_post1) | **POST** /subscriptions/{subscription}/beneficiaries/spid | Pre-registro de cuentas de beneficiarios SPID®
*Wire4Client::DepositantesApi* | [**get_depositants_using_get**](docs/DepositantesApi.md#get_depositants_using_get) | **GET** /subscriptions/{subscription}/depositants | Consulta de cuentas de depositantes
*Wire4Client::DepositantesApi* | [**register_depositants_using_post**](docs/DepositantesApi.md#register_depositants_using_post) | **POST** /subscriptions/{subscription}/depositants | Registra un nuevo depositante
*Wire4Client::EmpresasCoDiApi* | [**obtain_companies**](docs/EmpresasCoDiApi.md#obtain_companies) | **GET** /codi/companies | Consulta de empresas CODI®
*Wire4Client::EmpresasCoDiApi* | [**register_company_using_post**](docs/EmpresasCoDiApi.md#register_company_using_post) | **POST** /codi/companies | Registro de empresas CODI®
*Wire4Client::FacturasApi* | [**billings_report_by_id_using_get**](docs/FacturasApi.md#billings_report_by_id_using_get) | **GET** /billings/{id} | Consulta de facturas por identificador
*Wire4Client::FacturasApi* | [**billings_report_using_get**](docs/FacturasApi.md#billings_report_using_get) | **GET** /billings | Consulta de facturas
*Wire4Client::InstitucionesApi* | [**get_all_institutions_using_get**](docs/InstitucionesApi.md#get_all_institutions_using_get) | **GET** /institutions | Consulta de instituciones bancarias
*Wire4Client::LmitesDeMontosApi* | [**obtain_configurations_limits**](docs/LmitesDeMontosApi.md#obtain_configurations_limits) | **GET** /subscriptions/{suscription}/configurations | Consulta de configuraciones
*Wire4Client::LmitesDeMontosApi* | [**update_configurations**](docs/LmitesDeMontosApi.md#update_configurations) | **PUT** /subscriptions/{suscription}/configurations | Actualiza configuraciones por suscripción
*Wire4Client::OperacionesCoDiApi* | [**consult_codi_operations**](docs/OperacionesCoDiApi.md#consult_codi_operations) | **POST** /codi/charges | Consulta de operaciones
*Wire4Client::PeticionesDePagoPorCoDiApi* | [**consult_codi_request_by_order_id**](docs/PeticionesDePagoPorCoDiApi.md#consult_codi_request_by_order_id) | **GET** /codi/sales-point/charges | Consulta información de petición por orderId
*Wire4Client::PeticionesDePagoPorCoDiApi* | [**generate_codi_code_qr**](docs/PeticionesDePagoPorCoDiApi.md#generate_codi_code_qr) | **POST** /codi/sales-point/charges | Genera código QR
*Wire4Client::PuntosDeVentaCoDiApi* | [**create_sales_point**](docs/PuntosDeVentaCoDiApi.md#create_sales_point) | **POST** /codi/companies/salespoint | Registro de punto de venta.
*Wire4Client::PuntosDeVentaCoDiApi* | [**obtain_sale_points**](docs/PuntosDeVentaCoDiApi.md#obtain_sale_points) | **GET** /codi/companies/salespoint | Consulta de puntos de venta
*Wire4Client::SaldoApi* | [**get_balance_using_get**](docs/SaldoApi.md#get_balance_using_get) | **GET** /subscriptions/{subscription}/balance | Consulta los saldo de una cuenta
*Wire4Client::SuscripcionesApi* | [**change_subscription_status_using_put**](docs/SuscripcionesApi.md#change_subscription_status_using_put) | **PUT** /subscriptions/{subscription}/status | Cambia el estatus de la suscripción
*Wire4Client::SuscripcionesApi* | [**change_subscription_use_using_patch**](docs/SuscripcionesApi.md#change_subscription_use_using_patch) | **PATCH** /subscriptions/{subscription} | Cambia el uso de la suscripción
*Wire4Client::SuscripcionesApi* | [**pre_enrollment_monex_user_using_post**](docs/SuscripcionesApi.md#pre_enrollment_monex_user_using_post) | **POST** /subscriptions/pre-subscription | Pre-registro de una suscripción
*Wire4Client::SuscripcionesApi* | [**remove_enrollment_user_using_delete**](docs/SuscripcionesApi.md#remove_enrollment_user_using_delete) | **DELETE** /subscriptions/{subscription} | Elimina suscripción por su identificador.
*Wire4Client::SuscripcionesApi* | [**remove_subscription_pending_status_using_delete**](docs/SuscripcionesApi.md#remove_subscription_pending_status_using_delete) | **DELETE** /subscriptions/pre-subscription/{subscription} | Elimina pre-registro de suscripción
*Wire4Client::TransferenciasSPEIApi* | [**create_authorization_transactions_group**](docs/TransferenciasSPEIApi.md#create_authorization_transactions_group) | **POST** /subscriptions/{subscription}/transactions/group | Agrupa transacciones bajo un request_id 
*Wire4Client::TransferenciasSPEIApi* | [**drop_transactions_pending_using_delete**](docs/TransferenciasSPEIApi.md#drop_transactions_pending_using_delete) | **DELETE** /subscriptions/{subscription}/transactions/outcoming/spei/request/{requestId} | Eliminación de transferencias SPEI® pendientes
*Wire4Client::TransferenciasSPEIApi* | [**incoming_spei_transactions_report_using_get**](docs/TransferenciasSPEIApi.md#incoming_spei_transactions_report_using_get) | **GET** /subscriptions/{subscription}/transactions/incoming/spei | Consulta de transferencias recibidas
*Wire4Client::TransferenciasSPEIApi* | [**out_comming_spei_request_id_transactions_report_using_get**](docs/TransferenciasSPEIApi.md#out_comming_spei_request_id_transactions_report_using_get) | **GET** /subscriptions/{subscription}/transactions/outcoming/spei/{requestId} | Consulta de transferencias de salida por identificador de petición
*Wire4Client::TransferenciasSPEIApi* | [**outgoing_spei_transactions_report_using_get**](docs/TransferenciasSPEIApi.md#outgoing_spei_transactions_report_using_get) | **GET** /subscriptions/{subscription}/transactions/outcoming/spei | Consulta de transferencias realizadas
*Wire4Client::TransferenciasSPEIApi* | [**register_outgoing_spei_transaction_using_post**](docs/TransferenciasSPEIApi.md#register_outgoing_spei_transaction_using_post) | **POST** /subscriptions/{subscription}/transactions/outcoming/spei | Registro de transferencias
*Wire4Client::TransferenciasSPIDApi* | [**get_spid_classifications_using_get**](docs/TransferenciasSPIDApi.md#get_spid_classifications_using_get) | **GET** /subscriptions/{subscription}/beneficiaries/spid/classifications | Consulta de clasificaciones para operaciones SPID®
*Wire4Client::TransferenciasSPIDApi* | [**register_outgoing_spid_transaction_using_post**](docs/TransferenciasSPIDApi.md#register_outgoing_spid_transaction_using_post) | **POST** /subscriptions/{subscription}/transactions/outcoming/spid | Registro de transferencias SPID®
*Wire4Client::WebhooksApi* | [**get_webhook**](docs/WebhooksApi.md#get_webhook) | **GET** /webhooks/{webhook_id} | Consulta de Webhook
*Wire4Client::WebhooksApi* | [**get_webhooks**](docs/WebhooksApi.md#get_webhooks) | **GET** /webhooks | Consulta la lista de Webhooks
*Wire4Client::WebhooksApi* | [**register_webhook**](docs/WebhooksApi.md#register_webhook) | **POST** /webhooks | Alta de Webhook


## Documentation for Models

 - [Wire4Client::Account](docs/Account.md)
 - [Wire4Client::AccountDetail](docs/AccountDetail.md)
 - [Wire4Client::AccountReassigned](docs/AccountReassigned.md)
 - [Wire4Client::AccountRequest](docs/AccountRequest.md)
 - [Wire4Client::AccountResponse](docs/AccountResponse.md)
 - [Wire4Client::AccountSpid](docs/AccountSpid.md)
 - [Wire4Client::AddressCompany](docs/AddressCompany.md)
 - [Wire4Client::AmountRequest](docs/AmountRequest.md)
 - [Wire4Client::AuthorizationTransactionGroup](docs/AuthorizationTransactionGroup.md)
 - [Wire4Client::AuthorizedBeneficiariesResponse](docs/AuthorizedBeneficiariesResponse.md)
 - [Wire4Client::AuthorizedUsers](docs/AuthorizedUsers.md)
 - [Wire4Client::Balance](docs/Balance.md)
 - [Wire4Client::BalanceListResponse](docs/BalanceListResponse.md)
 - [Wire4Client::BeneficiariesQueryRegisterStatus](docs/BeneficiariesQueryRegisterStatus.md)
 - [Wire4Client::BeneficiariesResponse](docs/BeneficiariesResponse.md)
 - [Wire4Client::BeneficiaryInstitution](docs/BeneficiaryInstitution.md)
 - [Wire4Client::Billing](docs/Billing.md)
 - [Wire4Client::BillingTransaction](docs/BillingTransaction.md)
 - [Wire4Client::CepResponse](docs/CepResponse.md)
 - [Wire4Client::CepSearchBanxico](docs/CepSearchBanxico.md)
 - [Wire4Client::CertificateRequest](docs/CertificateRequest.md)
 - [Wire4Client::CodiCodeQrResponseDTO](docs/CodiCodeQrResponseDTO.md)
 - [Wire4Client::CodiCodeRequestDTO](docs/CodiCodeRequestDTO.md)
 - [Wire4Client::CodiOperationResponseDTO](docs/CodiOperationResponseDTO.md)
 - [Wire4Client::CodiOperationsFiltersRequestDTO](docs/CodiOperationsFiltersRequestDTO.md)
 - [Wire4Client::CompanyRegistered](docs/CompanyRegistered.md)
 - [Wire4Client::CompanyRequested](docs/CompanyRequested.md)
 - [Wire4Client::Compay](docs/Compay.md)
 - [Wire4Client::ConfigurationsLimits](docs/ConfigurationsLimits.md)
 - [Wire4Client::ContactRequest](docs/ContactRequest.md)
 - [Wire4Client::ContractDetailRequest](docs/ContractDetailRequest.md)
 - [Wire4Client::ContractDetailResponse](docs/ContractDetailResponse.md)
 - [Wire4Client::Deposit](docs/Deposit.md)
 - [Wire4Client::DepositAuthorizationRequest](docs/DepositAuthorizationRequest.md)
 - [Wire4Client::Depositant](docs/Depositant.md)
 - [Wire4Client::DepositantsRegister](docs/DepositantsRegister.md)
 - [Wire4Client::DepositantsResponse](docs/DepositantsResponse.md)
 - [Wire4Client::DepositsAuthorizationResponse](docs/DepositsAuthorizationResponse.md)
 - [Wire4Client::DetailedErrorResponse](docs/DetailedErrorResponse.md)
 - [Wire4Client::ErrorResponse](docs/ErrorResponse.md)
 - [Wire4Client::GetDepositants](docs/GetDepositants.md)
 - [Wire4Client::Institution](docs/Institution.md)
 - [Wire4Client::InstitutionsList](docs/InstitutionsList.md)
 - [Wire4Client::Item](docs/Item.md)
 - [Wire4Client::MessageAccountBeneficiary](docs/MessageAccountBeneficiary.md)
 - [Wire4Client::MessageCEP](docs/MessageCEP.md)
 - [Wire4Client::MessageCodiAction](docs/MessageCodiAction.md)
 - [Wire4Client::MessageConfigurationsLimits](docs/MessageConfigurationsLimits.md)
 - [Wire4Client::MessageDepositAuthorizationRequest](docs/MessageDepositAuthorizationRequest.md)
 - [Wire4Client::MessageDepositReceived](docs/MessageDepositReceived.md)
 - [Wire4Client::MessageInstitution](docs/MessageInstitution.md)
 - [Wire4Client::MessagePayment](docs/MessagePayment.md)
 - [Wire4Client::MessagePaymentStatePending](docs/MessagePaymentStatePending.md)
 - [Wire4Client::MessageRequestChanged](docs/MessageRequestChanged.md)
 - [Wire4Client::MessageSalesPoint](docs/MessageSalesPoint.md)
 - [Wire4Client::MessageSubscription](docs/MessageSubscription.md)
 - [Wire4Client::MessageUserAuthorized](docs/MessageUserAuthorized.md)
 - [Wire4Client::MessageWebHook](docs/MessageWebHook.md)
 - [Wire4Client::Operations](docs/Operations.md)
 - [Wire4Client::PagerResponseDto](docs/PagerResponseDto.md)
 - [Wire4Client::Payment](docs/Payment.md)
 - [Wire4Client::PaymentCODI](docs/PaymentCODI.md)
 - [Wire4Client::PaymentRequestCodiResponseDTO](docs/PaymentRequestCodiResponseDTO.md)
 - [Wire4Client::PaymentsRequestId](docs/PaymentsRequestId.md)
 - [Wire4Client::Person](docs/Person.md)
 - [Wire4Client::PreEnrollmentData](docs/PreEnrollmentData.md)
 - [Wire4Client::PreEnrollmentResponse](docs/PreEnrollmentResponse.md)
 - [Wire4Client::PreMonexAuthorization](docs/PreMonexAuthorization.md)
 - [Wire4Client::Relationship](docs/Relationship.md)
 - [Wire4Client::RelationshipsResponse](docs/RelationshipsResponse.md)
 - [Wire4Client::SalesPoint](docs/SalesPoint.md)
 - [Wire4Client::SalesPointFound](docs/SalesPointFound.md)
 - [Wire4Client::SalesPointRequest](docs/SalesPointRequest.md)
 - [Wire4Client::SalesPointRespose](docs/SalesPointRespose.md)
 - [Wire4Client::ServiceBanking](docs/ServiceBanking.md)
 - [Wire4Client::SpidBeneficiariesResponse](docs/SpidBeneficiariesResponse.md)
 - [Wire4Client::SpidBeneficiaryResponse](docs/SpidBeneficiaryResponse.md)
 - [Wire4Client::SpidClassificationDTO](docs/SpidClassificationDTO.md)
 - [Wire4Client::SpidClassificationsResponseDTO](docs/SpidClassificationsResponseDTO.md)
 - [Wire4Client::SubscriptionChangeStatusRequest](docs/SubscriptionChangeStatusRequest.md)
 - [Wire4Client::TokenRequiredResponse](docs/TokenRequiredResponse.md)
 - [Wire4Client::TransactionErrorCode](docs/TransactionErrorCode.md)
 - [Wire4Client::TransactionOutgoing](docs/TransactionOutgoing.md)
 - [Wire4Client::TransactionOutgoingSpid](docs/TransactionOutgoingSpid.md)
 - [Wire4Client::TransactionsOutgoingRegister](docs/TransactionsOutgoingRegister.md)
 - [Wire4Client::UpdateConfigurationsRequestDTO](docs/UpdateConfigurationsRequestDTO.md)
 - [Wire4Client::UrlsRedirect](docs/UrlsRedirect.md)
 - [Wire4Client::UseServiceBanking](docs/UseServiceBanking.md)
 - [Wire4Client::UserCompany](docs/UserCompany.md)
 - [Wire4Client::WebHookDepositAuthorizationRequest](docs/WebHookDepositAuthorizationRequest.md)
 - [Wire4Client::WebHookDepositAuthorizationResponse](docs/WebHookDepositAuthorizationResponse.md)
 - [Wire4Client::Webhook](docs/Webhook.md)
 - [Wire4Client::WebhookRequest](docs/WebhookRequest.md)
 - [Wire4Client::WebhookResponse](docs/WebhookResponse.md)
 - [Wire4Client::WebhooksList](docs/WebhooksList.md)


## Documentation for Authorization

 All endpoints do not require authorization.

